Struct sp_runtime::offchain::HttpRequestId
pub struct HttpRequestId(pub u16);Expand description
Opaque type for offchain http requests.
Tuple Fields
0: u16Trait Implementations
impl Clone for HttpRequestId
impl Clone for HttpRequestId
fn clone(&self) -> HttpRequestId
fn clone(&self) -> HttpRequestId
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Debug for HttpRequestId
impl Debug for HttpRequestId
impl Decode for HttpRequestId
impl Decode for HttpRequestId
fn decode<__CodecInputEdqy>(
__codec_input_edqy: &mut __CodecInputEdqy
) -> Result<HttpRequestId, Error>where
__CodecInputEdqy: Input,
fn decode<__CodecInputEdqy>( __codec_input_edqy: &mut __CodecInputEdqy ) -> Result<HttpRequestId, Error>where __CodecInputEdqy: Input,
Attempt to deserialise the value from input.
fn decode_into<I>(
input: &mut I,
dst: &mut MaybeUninit<Self>
) -> Result<DecodeFinished, Error>where
I: Input,
fn decode_into<I>( input: &mut I, dst: &mut MaybeUninit<Self> ) -> Result<DecodeFinished, Error>where I: Input,
Attempt to deserialize the value from input into a pre-allocated piece of memory. Read more
fn skip<I>(input: &mut I) -> Result<(), Error>where
I: Input,
fn skip<I>(input: &mut I) -> Result<(), Error>where I: Input,
Attempt to skip the encoded value from input. Read more
fn encoded_fixed_size() -> Option<usize>
fn encoded_fixed_size() -> Option<usize>
Returns the fixed encoded size of the type. Read more
impl Encode for HttpRequestId
impl Encode for HttpRequestId
fn encode_to<__CodecOutputEdqy>(
&self,
__codec_dest_edqy: &mut __CodecOutputEdqy
)where
__CodecOutputEdqy: Output + ?Sized,
fn encode_to<__CodecOutputEdqy>( &self, __codec_dest_edqy: &mut __CodecOutputEdqy )where __CodecOutputEdqy: Output + ?Sized,
Convert self to a slice and append it to the destination.
fn using_encoded<R, F>(&self, f: F) -> Rwhere
F: FnOnce(&[u8]) -> R,
fn using_encoded<R, F>(&self, f: F) -> Rwhere F: FnOnce(&[u8]) -> R,
Convert self to a slice and then invoke the given closure with it.
fn encoded_size(&self) -> usize
fn encoded_size(&self) -> usize
Calculates the encoded size. Read more
impl Hash for HttpRequestId
impl Hash for HttpRequestId
impl Ord for HttpRequestId
impl Ord for HttpRequestId
impl PartialEq<HttpRequestId> for HttpRequestId
impl PartialEq<HttpRequestId> for HttpRequestId
fn eq(&self, other: &HttpRequestId) -> bool
fn eq(&self, other: &HttpRequestId) -> bool
This method tests for
self and other values to be equal, and is used
by ==.impl PartialOrd<HttpRequestId> for HttpRequestId
impl PartialOrd<HttpRequestId> for HttpRequestId
fn partial_cmp(&self, other: &HttpRequestId) -> Option<Ordering>
fn partial_cmp(&self, other: &HttpRequestId) -> Option<Ordering>
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for
self and other) and is used by the <=
operator. Read moreimpl PassBy for HttpRequestId
impl PassBy for HttpRequestId
type PassBy = Inner<HttpRequestId, u16>
type PassBy = Inner<HttpRequestId, u16>
The strategy that should be used to pass the type.
impl PassByInner for HttpRequestId
impl PassByInner for HttpRequestId
fn into_inner(self) -> <HttpRequestId as PassByInner>::Inner
fn into_inner(self) -> <HttpRequestId as PassByInner>::Inner
Consumes
self and returns the inner type.fn inner(&self) -> &<HttpRequestId as PassByInner>::Inner
fn inner(&self) -> &<HttpRequestId as PassByInner>::Inner
Returns the reference to the inner type.
fn from_inner(inner: <HttpRequestId as PassByInner>::Inner) -> HttpRequestId
fn from_inner(inner: <HttpRequestId as PassByInner>::Inner) -> HttpRequestId
Construct
Self from the given inner.impl Copy for HttpRequestId
impl EncodeLike<HttpRequestId> for HttpRequestId
impl Eq for HttpRequestId
impl StructuralEq for HttpRequestId
impl StructuralPartialEq for HttpRequestId